@@ -22,6 +22,19 @@
 #ifndef _PLAYER_H
 #define _PLAYER_H
 
+#define EFFECT_MIDI_COMMAND_VALUE 0x00
+#define EFFECT_PITCH_WHEEL 0x01
+#define EFFECT_END_BLOCK 0x02
+#define EFFECT_PLAYSEQ_POSITION 0x03
+#define EFFECT_STOP 0x04
+#define EFFECT_MIDI_COMMAND 0x05
+#define EFFECT_NOTE_DELAY 0x0b
+#define EFFECT_VELOCITY 0x0c
+#define EFFECT_CHANNEL_PRESSURE 0x0d
+#define EFFECT_TPL 0x0e
+#define EFFECT_TEMPO 0x0f
+#define EFFECT_NOT_DEFINED 0x10
+
 void play_song();
 void continue_song();
 void play_block();
@@ -30,6 +43,8 @@ void stop();
 
 /* SIGALRT signal handler for triggering the playroutine */
 void play_handler(int);
+void play_playseq_advance();
+void play_section_advance();
 /* Sets the timer structure according to a given BPM count */
 void play_set_timer(unsigned short);
 /* Plays a note using given instrument on a given channel */
