@@ -84,32 +84,26 @@ void gui_play_song() {
   gui_playseq_refresh();
   gui_section_refresh();
   gui_timer_refresh(0);
-
-  gtk_label_set_text(GTK_LABEL(gui_info_status), "Playing song");
 }
 
 void gui_continue_song() {
   if(editor.mode!=MODE_PLAY_SONG) {
     continue_song();
-
-    gtk_label_set_text(GTK_LABEL(gui_info_status), "Playing song");
+    gui_info_refresh();
   }
 }
 
 void gui_play_block() {
   play_block();
-
   tracker_set_patpos((Tracker *)gui_main_tracker, 0);
-
-  gtk_label_set_text(GTK_LABEL(gui_info_status), "Playing block");
+  gui_info_refresh();
   gui_timer_refresh(0);
 }
 
 void gui_continue_block() {
   if(editor.mode!=MODE_PLAY_BLOCK) {
     continue_block();
-
-    gtk_label_set_text(GTK_LABEL(gui_info_status), "Playing block");
+    gui_info_refresh();
   }
 }
 
@@ -117,7 +111,7 @@ void gui_stop() {
   stop();
     
   if(editor.mode!=MODE_IDLE)
-    gtk_label_set_text(GTK_LABEL(gui_info_status), "- Stopped -");
+    gui_info_refresh();
 }
 
 void gui_new() {
@@ -431,8 +425,7 @@ void gui_create() {
   gui_tempo_adjustment_tempo=(GtkWidget *)gtk_adjustment_new(125, 1,
 							 240, 1, 1, 0);
   gtk_signal_connect(GTK_OBJECT(gui_tempo_adjustment_tempo), "value_changed",
-		     GTK_SIGNAL_FUNC(gui_tempo_changed),
-		     (gpointer)&editor.song->tempo);
+		     GTK_SIGNAL_FUNC(gui_tempo_changed), NULL);
   w4=gtk_hscale_new(GTK_ADJUSTMENT(gui_tempo_adjustment_tempo));
   gtk_scale_set_digits(GTK_SCALE(w4), 0);
   gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
@@ -442,8 +435,7 @@ void gui_create() {
   gtk_box_pack_start(GTK_BOX(w3), w4, FALSE, FALSE, 4);
   gui_tempo_adjustment_tpl=(GtkWidget *)gtk_adjustment_new(6, 1, 32, 1, 1, 0);
   gtk_signal_connect(GTK_OBJECT(gui_tempo_adjustment_tpl), "value_changed",
-		     GTK_SIGNAL_FUNC(gui_tempo_changed),
-		     (gpointer)&editor.song->ticksperline);
+		     GTK_SIGNAL_FUNC(gui_tpl_changed), NULL);
   w4=gtk_hscale_new(GTK_ADJUSTMENT(gui_tempo_adjustment_tpl));
   gtk_scale_set_digits(GTK_SCALE(w4), 0);
   gtk_box_pack_start(GTK_BOX(w3), w4, TRUE, TRUE, 4);
@@ -786,6 +778,18 @@ void gui_info_refresh() {
 	   editor.block, editor.song->numblocks-1, 0, 0,
 	   editor.song->tempo, editor.song->ticksperline);
   gtk_window_set_title(GTK_WINDOW(gui_main_window), title); 
+
+  switch(editor.mode) {
+  case MODE_PLAY_SONG:
+    gtk_label_set_text(GTK_LABEL(gui_info_status), "Playing song");
+    break;
+  case MODE_PLAY_BLOCK:
+    gtk_label_set_text(GTK_LABEL(gui_info_status), "Playing block");
+    break;
+  case MODE_IDLE:
+    gtk_label_set_text(GTK_LABEL(gui_info_status), "- Stopped -");
+    break;
+  }
 }
 
 void gui_timer_refresh(unsigned int seconds) {
@@ -1185,7 +1189,11 @@ void gui_main_changed(GtkAdjustment *adjustment, gpointer user_data) {
 }
 
 void gui_tempo_changed(GtkAdjustment *adjustment, gpointer user_data) {
-  unsigned char *data=(unsigned char *)user_data;
-  *data=(unsigned char)adjustment->value;
+  song_settempo(editor.song, (unsigned char)adjustment->value);
+  gui_info_refresh();
+}
+
+void gui_tpl_changed(GtkAdjustment *adjustment, gpointer user_data) {
+  song_settpl(editor.song, (unsigned char)adjustment->value);
   gui_info_refresh();
 }
